<?php

/**
 * @file
 * Administration forms for Commerce Caledon.
 */

/**
 * Menu callback; Displays the administration settings for Caledon Payment.
 */
function commerce_caledon_admin_settings() {
  $form = array();

  $form['commerce_caledon'] = array(
    '#type' => 'fieldset',
    '#title' => t('Caledon Settings'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );

  $form['commerce_caledon']['commerce_caledon_title'] = array(
    '#type' => 'textfield',
    '#title' => t('Title'),
    '#default_value' => variable_get('commerce_caledon_title', 'Caledon'),
    '#description' => t('Override the default title of the commerce caledon payment method.'),
  );

  $form['commerce_caledon']['commerce_caledon_declined_text'] = array(
    '#type' => 'textfield',
    '#title' => t('Card problem text'),
    '#default_value' => variable_get('commerce_caledon_error_text', 'There was a problem processing your card. Please enter your information again or try a different card.'),
    '#description' => t('Override the default text displayed to users on card declined errors.'),
  );

  $form['commerce_caledon']['commerce_caledon_connect_err_text'] = array(
    '#type' => 'textfield',
    '#title' => t('Connection problem text'),
    '#default_value' => variable_get('commerce_caledon_connect_err_text', 'There was an error with your request. Please try again, and contact the site administrator if this problem persists.'),
    '#description' => t('Override the default text displayed to users if there are problems connecting to Caledon.'),
  );

  $form['commerce_caledon']['commerce_caledon_production'] = array(
    '#type' => 'radios',
    '#title' => t('Production status'),
    '#options' => array(
      0 => t('Testing'),
      1 => t('Production'),
    ),
    '#default_value' => variable_get('commerce_caledon_production', 0),
    '#required' => TRUE,
  );

  $form['commerce_caledon']['commerce_caledon_terminal_id'] = array(
    '#type' => 'textfield',
    '#title' => t('Terminal ID'),
    '#default_value' => variable_get('commerce_caledon_terminal_id', ''),
    '#required' => TRUE,
  );

  $form['commerce_caledon']['commerce_caledon_terminal_id_test'] = array(
    '#type' => 'textfield',
    '#title' => t('Terminal ID for TESTING'),
    '#default_value' => variable_get('commerce_caledon_terminal_id_test', ''),
    '#required' => TRUE,
  );

  $form['commerce_caledon']['commerce_caledon_collect_cvd'] = array(
    '#type' => 'radios',
    '#title' => t('Collect CVD Code?'),
    '#options' => array( 0 => 'No', 1 => 'Yes' ),
    '#default_value' => variable_get('commerce_caledon_collect_cvd', 0),
    '#required' => TRUE,
  );

  $form['commerce_caledon']['commerce_caledon_use_avs'] = array(
    '#type' => 'radios',
    '#title' => t('Use address verifications service (AVS)?'),
    '#options' => array( 0 => 'No', 1 => 'Yes' ),
    '#default_value' => variable_get('commerce_caledon_use_avs', 0),
    '#required' => TRUE,
    '#description' => t('Not yet implemented.'),
  );

  $path = drupal_get_path('module', 'commerce_caledon') . '/images';
  $card_options = commerce_caledon_cards();
  foreach($card_options as $card_code => $card_name) {
    $src = $path . '/' . $card_code . '.png';
    $img = '<img src="/' . $src . '" alt="' . $card_name . '" style="vertical-align: bottom;" />';
    $txt = ($card_code != 'null') ? $img : $card_name;
    $options[$card_code] = $txt;
  }

  $form['commerce_caledon']['commerce_caledon_cards'] = array(
    '#type' => 'checkboxes',
    '#title' => 'Display card icons',
    '#options' => $options,
    '#default_value' => variable_get('commerce_caledon_cards', array()),
    '#description' => t('Choose card icons to display during checkout. Note that this does not affect card processing, it just allows you to display what cards are accepted using your merchant account. If you select "None" then no icons will be shown.'),
  );


  return system_settings_form($form);
}
